==> cxf-testutils-2.0.6.11-fuse-sources.jar: org/apache/type_test/types3/OccuringChoice1.java <==

package org.apache.type_test.types3;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for OccuringChoice1 complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OccuringChoice1">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;choice maxOccurs="unbounded" minOccurs="0">
 *         &lt;element name="varFloat" type="{http://www.w3.org/2001/XMLSchema}float"/>
 *         &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *       &lt;/choice>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OccuringChoice1", propOrder = {
    "varFloatOrVarInt"
})
public class OccuringChoice1 {

    @XmlElements({
        @XmlElement(name = "varFloat", namespace = "http://apache.org/type_test/types3", required = true, type = Float.class, nillable = true),
        @XmlElement(name = "varInt", namespace = "http://apache.org/type_test/types3", required = true, type = Integer.class)
    })
    protected List<Comparable> varFloatOrVarInt;

    /**
     * Gets the value of the varFloatOrVarInt property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the varFloatOrVarInt property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVarFloatOrVarInt().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Float }
     * {@link Integer }
     * 
     * 
     */
    public List<Comparable> getVarFloatOrVarInt() {
        if (varFloatOrVarInt == null) {
            varFloatOrVarInt = new ArrayList<Comparable>();
        }
        return this.varFloatOrVarInt;
    }

}

==> cxf-testutils-2.0.12.0-fuse-sources.jar: org/apache/type_test/types3/OccuringChoice1.java <==

package org.apache.type_test.types3;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for OccuringChoice1 complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OccuringChoice1">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;choice maxOccurs="unbounded" minOccurs="0">
 *         &lt;element name="varFloat" type="{http://www.w3.org/2001/XMLSchema}float"/>
 *         &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *       &lt;/choice>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OccuringChoice1", propOrder = {
    "varFloatOrVarInt"
})
public class OccuringChoice1 {

    @XmlElements({
        @XmlElement(name = "varInt", namespace = "http://apache.org/type_test/types3", required = true, type = Integer.class),
        @XmlElement(name = "varFloat", namespace = "http://apache.org/type_test/types3", required = true, type = Float.class, nillable = true)
    })
    protected List<Comparable> varFloatOrVarInt;

    /**
     * Gets the value of the varFloatOrVarInt property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the varFloatOrVarInt property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVarFloatOrVarInt().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Integer }
     * {@link Float }
     * 
     * 
     */
    public List<Comparable> getVarFloatOrVarInt() {
        if (varFloatOrVarInt == null) {
            varFloatOrVarInt = new ArrayList<Comparable>();
        }
        return this.varFloatOrVarInt;
    }

}
